Stan Math Library: stan/math/prim/scal/fun/is_nan.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_nan.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_IS_NAN_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_IS_NAN_HPP
3
4 #include <boost/math/special_functions/fpclassify.hpp>
5
6 namespace stan {
7
8 namespace math {
9
18 inline bool is_nan(double x) {
19 return boost::math::isnan(x);
20 }
21
22 }
23 }
24
25 #endif
stan
Definition: log_sum_exp.hpp:8
boost::math::isnan
bool isnan(const stan::math::var &v)
Checks if the given number is NaN.
Definition: boost_isnan.hpp:22
stan::math::is_nan
int is_nan(const fvar< T > &x)
Returns 1 if the input's value is NaN and 0 otherwise.
Definition: is_nan.hpp:22

[ Stan Home Page ] © 2011–2016, Stan Development Team.